colour.constants.codata Module — Colour 0.3.0 documentation

# colour.constants.codata Module

## Fundamental Physical Constants

Defines various constants from recommended values by the Committee on Data for Science and Technology (CODATA).

`colour.constants.codata.` `AVOGADRO_CONSTANT` = 6.02214179e+23

  Avogadro constant.

  AVOGADRO_CONSTANT : numeric

`colour.constants.codata.` `BOLTZMANN_CONSTANT` = 1.38065e-23

  Boltzmann constant.

  BOLTZMANN_CONSTANT : numeric

`colour.constants.codata.` `LIGHT_SPEED` = 299792458

  Speed of light in vacuum.

  LIGHT_SPEED : numeric

`colour.constants.codata.` `PLANCK_CONSTANT` = 6.62607e-34

  Planck constant.

  PLANCK_CONSTANT : numeric